==> heptapod-rails-0.16.1.tar.gz: heptapod-rails-0.16.1/app/serializers/pipeline_serializer.rb <==
# frozen_string_literal: true

class PipelineSerializer < BaseSerializer
  include WithPagination
  entity PipelineDetailsEntity

  # rubocop: disable CodeReuse/ActiveRecord
  def represent(resource, opts = {})
    if resource.is_a?(ActiveRecord::Relation)
      resource = resource.preload(preloaded_relations)
    end

    if paginated?
      resource = paginator.paginate(resource)
    end

    if opts.delete(:preload)
      resource = Gitlab::Ci::Pipeline::Preloader.preload!(resource)
    end

    super(resource, opts)
  end
  # rubocop: enable CodeReuse/ActiveRecord

  def represent_status(resource)
    return {} unless resource.present?

    data = represent(resource, { only: [{ details: [:status] }] })
    data.dig(:details, :status) || {}
  end

  def represent_stages(resource)
    return {} unless resource.present?

    data = represent(resource, { only: [{ details: [:stages] }], preload: true })
    data.dig(:details, :stages) || []
  end

  private

  def preloaded_relations
    [
      :cancelable_statuses,
      :latest_statuses_ordered_by_stage,
      :latest_builds_report_results,
      :manual_actions,
      :retryable_builds,
      :scheduled_actions,
      :stages,
      :trigger_requests,
      :user,
      {
        downloadable_artifacts: {
          project: [:route, { namespace: :route }],
          job: []
        },
        failed_builds: %i(project metadata),
        merge_request: {
          source_project: [:route, { namespace: :route }],
          target_project: [:route, { namespace: :route }]
        },
        pending_builds: :project,
        project: [:route, { namespace: :route }],
        triggered_by_pipeline: [{ project: [:route, { namespace: :route }] }, :user],
        triggered_pipelines: [{ project: [:route, { namespace: :route }] }, :user, :source_job]
      }
    ]
  end
end

==> heptapod-rails-0.21.3.tar.gz: heptapod-rails-0.21.3/app/serializers/pipeline_serializer.rb <==
# frozen_string_literal: true

class PipelineSerializer < BaseSerializer
  include WithPagination
  entity PipelineDetailsEntity

  # rubocop: disable CodeReuse/ActiveRecord
  def represent(resource, opts = {})
    if resource.is_a?(ActiveRecord::Relation)
      resource = resource.preload(preloaded_relations)
    end

    if paginated?
      resource = paginator.paginate(resource)
    end

    if opts.delete(:preload)
      resource = Gitlab::Ci::Pipeline::Preloader.preload!(resource)
    end

    super(resource, opts)
  end
  # rubocop: enable CodeReuse/ActiveRecord

  def represent_status(resource)
    return {} unless resource.present?

    data = represent(resource, { only: [{ details: [:status] }] })
    data.dig(:details, :status) || {}
  end

  def represent_stages(resource)
    return {} unless resource.present?

    data = represent(resource, { only: [{ details: [:stages] }], preload: true })
    data.dig(:details, :stages) || []
  end

  private

  def preloaded_relations
    [
      :cancelable_statuses,
      :latest_statuses_ordered_by_stage,
      :retryable_builds,
      :stages,
      :latest_statuses,
      :trigger_requests,
      :user,
      {
        manual_actions: :metadata,
        scheduled_actions: :metadata,
        downloadable_artifacts: {
          project: [:route, { namespace: :route }],
          job: []
        },
        failed_builds: %i(project metadata),
        merge_request: {
          source_project: [:route, { namespace: :route }],
          target_project: [:route, { namespace: :route }]
        },
        pending_builds: :project,
        project: [:route, { namespace: :route }],
        triggered_by_pipeline: [{ project: [:route, { namespace: :route }] }, :user],
        triggered_pipelines: [
          {
            project: [:route, { namespace: :route }]
          },
          :source_job,
          :latest_statuses,
          :user
        ]
      }
    ]
  end
end

PipelineSerializer.prepend_if_ee('EE::PipelineSerializer')
